.. _ReferencePage:

=============
API Reference
=============

You can find automatically generated documentation for each module in the ``zCluster`` package below. Note that 
some functions listed here may not be used by any of the scripts found in the ``bin/`` directory.

catalogs
--------

.. automodule:: zCluster.catalogs
   :members:

clusters
--------

.. automodule:: zCluster.clusters
   :members:

PhotoRedshiftEngine
-------------------

.. automodule:: zCluster.PhotoRedshiftEngine
   :members:


retrievers
----------

.. automodule:: zCluster.retrievers
   :members:

